import { Emoji } from "./emojis";
export declare type L33t1fySubstitution = "numbers" | "big" | "symbols" | "homophones";
export interface L33t1fyOptions {
    /** types of l33t1fy substitutions */
    substitutionType: L33t1fySubstitution;
}
export declare type FitzpatrickModifier = "🏻" | "🏼" | "🏽" | "🏾" | "🏿";
export interface ClapifyOptions {
    fitzpatrick: FitzpatrickModifier;
}
export interface EmojifyOptions {
    fitzpatrick: FitzpatrickModifier;
}
/**
 * Transforms text to be all caps with clap emojis between each word
 * @param text the text to be transformed
 * @returns the text with clap emojis
 */
export declare function clapify(text: string, options: ClapifyOptions): string;
/**
 * Transforms text to have alternating capitalization
 * @param text the text to be transformed
 * @returns the text with alternating capitalization
 */
export declare function altCapify(text: string): string;
/**
 * Applies fitzpatrick modifier to an emoji
 * @param emoji the emoji to modify
 * @param modifier the fitzpatrick modifier
 * @returns the modified emoji character
 */
export declare function applyFitzpatrick(emoji: Emoji, modifier: FitzpatrickModifier): string;
/**
 * Inserts emojis into text
 * @param text the source text
 * @returns the text with emojis
 */
export declare function emojify(text: string, options: EmojifyOptions): string;
/**
 * Translates text into keyboard smashing
 * @param text the text to be translated
 * @returns the generated keysmash text
 */
export declare function smashify(text: string): string;
/**
 * Translates the text into l33t sp34k
 * @param text the text to be translated
 * @param options options
 * @returns the translated text
 */
export declare function l33t1fy(text: string, options: L33t1fyOptions): string;
/**
 * Text transform for spaced out text
 * @param text the text to be transformed
 * @returns the spaced out text
 */
export declare function spaceify(text: string): string;
